@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: js-jquery
-version: 1.12.2
-id: js-jquery-1.12.2-60fc2af6d883a5909b2d58515558f582
-key: jsjqu_Ffevaho3mcvBCDgBCFhunA
+version: 1.12.3
+id: js-jquery-1.12.3-5118b3168089907b4a923302e26b97c5
+key: jsjqu_CUmExJgYMIY8Jk3i6gczmP
 license: MIT
 copyright: Neil Mitchell 2014-2016
 maintainer: Neil Mitchell <ndmitchell@gmail.com>
@@ -21,10 +21,10 @@ exposed-modules:
     Language.Javascript.JQuery
 hidden-modules: Paths_js_jquery
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/js-jquery-1.12.2
-library-dirs: /usr/lib/ghc-7.10.3/site-local/js-jquery-1.12.2
-data-dir: /usr/share/arm-linux-ghc-7.10.3/js-jquery-1.12.2
-hs-libraries: HSjs-jquery-1.12.2-Ffevaho3mcvBCDgBCFhunA
+import-dirs: /usr/lib/ghc-7.10.3/site-local/js-jquery-1.12.3
+library-dirs: /usr/lib/ghc-7.10.3/site-local/js-jquery-1.12.3
+data-dir: /usr/share/arm-linux-ghc-7.10.3/js-jquery-1.12.3
+hs-libraries: HSjs-jquery-1.12.3-CUmExJgYMIY8Jk3i6gczmP
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
 haddock-interfaces: /usr/share/doc/haskell-js-jquery/html/js-jquery.haddock
